@@ -3,6 +3,7 @@
 #include "idoscalemenuitem.h"
 #include "idocalendarmenuitem.h"
 #include "idoentrymenuitem.h"
+#include "idoswitchmenuitem.h"
 #include "config.h"
 
 static void
@@ -27,6 +28,7 @@ main (int argc, char *argv[])
   GtkWidget *root;
   GtkWidget *menubar;
   GtkWidget *image;
+  GtkWidget *label;
 
   g_unsetenv ("UBUNTU_MENUPROXY");
 
@@ -38,11 +40,7 @@ main (int argc, char *argv[])
   g_signal_connect (window, "delete-event",
                     G_CALLBACK (gtk_main_quit), NULL);
 
-#ifdef USE_GTK3
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-  vbox = gtk_vbox_new (FALSE, 0);
-#endif
 
   gtk_container_add (GTK_CONTAINER (window), vbox);
 
@@ -76,6 +74,12 @@ main (int argc, char *argv[])
   menuitem = ido_entry_menu_item_new ();
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
+  menuitem = ido_switch_menu_item_new ();
+  label = gtk_label_new ("This is a switch");
+  gtk_widget_show(label);
+  gtk_container_add (ido_switch_menu_item_get_content_area(IDO_SWITCH_MENU_ITEM(menuitem)), label);
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+
   menuitem = ido_calendar_menu_item_new ();
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
